@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from boto import exception as boto_exception
+from botocore import exceptions as botocore_exceptions
 from cinderclient import exceptions as cinder_exception
 from glanceclient.common import exceptions as glance_exception
 from keystoneclient import exceptions as keystone_exception
@@ -58,7 +58,7 @@ class ApiInitTestCase(base.BaseTestCase):
         expected_xml = fakes.XML_RESULT_TEMPLATE % {
             'action': 'FakeAction',
             'api_version': 'fake_v1',
-            'request_id': self.fake_context.request_id.decode("ascii"),
+            'request_id': self.fake_context.request_id,
             'data': '<fakeTag>fake_data</fakeTag>'}
         self.assertThat(res.body.decode("utf-8"),
                         matchers.XMLMatches(expected_xml))
@@ -78,7 +78,7 @@ class ApiInitTestCase(base.BaseTestCase):
             expected_xml = fakes.XML_ERROR_TEMPLATE % {
                 'code': code,
                 'message': message,
-                'request_id': self.fake_context.request_id.decode("ascii")}
+                'request_id': self.fake_context.request_id}
             self.assertThat(res.body.decode("utf-8"),
                             matchers.XMLMatches(expected_xml))
             self.controller.fake_action.assert_called_once_with(
@@ -99,6 +99,10 @@ class ApiInitTestCase(base.BaseTestCase):
         do_check(neutron_exception.BadRequest(message='fake_msg'),
                  400, 'BadRequest', 'fake_msg')
         do_check(keystone_exception.BadRequest(message='fake_msg'),
-                 400, 'BadRequest', 'fake_msg')
-        do_check(boto_exception.S3ResponseError(400, '', 'fake_msg'),
-                 400, 'S3ResponseError', 'fake_msg')
+                 400, 'BadRequest', 'fake_msg (HTTP 400)')
+        do_check(botocore_exceptions.ClientError({'Error':
+                                                  {'Code': '', 'Message': ''},
+                                                  'Code': 'FakeCode',
+                                                  'Message': 'fake_msg'},
+                                                 'register_image'),
+                 400, 'FakeCode', 'fake_msg')
